@@ -8,6 +8,7 @@ from typing import List, Tuple
 from mypy_boto3_builder.structures.master_package import MasterPackage
 from mypy_boto3_builder.writers.utils import (
     blackify,
+    fix_pypi_headers,
     format_md,
     insert_md_toc,
     render_jinja2_template,
@@ -78,6 +79,7 @@ def write_master_package(
             content = blackify(content, file_path)
         if file_path.suffix == ".md":
             content = insert_md_toc(content)
+            content = fix_pypi_headers(content)
             content = format_md(content)
 
         if not file_path.exists() or file_path.read_text() != content:
